==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QStencilTestArguments.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies arguments for stencil test</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html">Qt3DRender::QStencilTestArguments</a></p>
 */
public final class QStencilTestArguments extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTestArguments.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#StencilFaceMode-enum">Qt3DRender::QStencilTestArguments::StencilFaceMode</a></p>
     */
    public enum StencilFaceMode implements io.qt.QtEnumerator {
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private StencilFaceMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StencilFaceMode resolve(int value) {
            switch (value) {
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#StencilFunction-enum">Qt3DRender::QStencilTestArguments::StencilFunction</a></p>
     */
    public enum StencilFunction implements io.qt.QtEnumerator {
        Never(512),
        Always(519),
        Less(513),
        LessOrEqual(515),
        Equal(514),
        GreaterOrEqual(518),
        Greater(516),
        NotEqual(517);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private StencilFunction(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StencilFunction resolve(int value) {
            switch (value) {
            case 512: return Never;
            case 519: return Always;
            case 513: return Less;
            case 515: return LessOrEqual;
            case 514: return Equal;
            case 518: return GreaterOrEqual;
            case 516: return Greater;
            case 517: return NotEqual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::comparisonMaskChanged(uint)</a></p>
     */
    @io.qt.QtPropertyNotify(name="comparisonMask")
    public final Signal1<@io.qt.QtPrimitiveType Integer> comparisonMaskChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#faceMode-prop">Qt3DRender::QStencilTestArguments::faceModeChanged(Qt3DRender::QStencilTestArguments::StencilFaceMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="faceMode")
    public final Signal1<io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode> faceModeChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::referenceValueChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="referenceValue")
    public final Signal1<@io.qt.QtPrimitiveType Integer> referenceValueChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::stencilFunctionChanged(Qt3DRender::QStencilTestArguments::StencilFunction)</a></p>
     */
    @io.qt.QtPropertyNotify(name="stencilFunction")
    public final Signal1<io.qt.qt3d.render.QStencilTestArguments.StencilFunction> stencilFunctionChanged = new Signal1<>();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::comparisonMask()const</a></p>
     */
    @io.qt.QtPropertyReader(name="comparisonMask")
    @io.qt.QtUninvokable
    public final int comparisonMask(){
        return comparisonMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int comparisonMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#faceMode-prop">Qt3DRender::QStencilTestArguments::faceMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="faceMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode faceMode(){
        return io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode.resolve(faceMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int faceMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::referenceValue()const</a></p>
     */
    @io.qt.QtPropertyReader(name="referenceValue")
    @io.qt.QtUninvokable
    public final int referenceValue(){
        return referenceValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int referenceValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::setComparisonMask(uint)</a></p>
     */
    @io.qt.QtPropertyWriter(name="comparisonMask")
    public final void setComparisonMask(int comparisonMask){
        setComparisonMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), comparisonMask);
    }
    
    private native void setComparisonMask_native_uint(long __this__nativeId, int comparisonMask);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::setReferenceValue(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="referenceValue")
    public final void setReferenceValue(int referenceValue){
        setReferenceValue_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), referenceValue);
    }
    
    private native void setReferenceValue_native_int(long __this__nativeId, int referenceValue);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::setStencilFunction(Qt3DRender::QStencilTestArguments::StencilFunction)</a></p>
     */
    @io.qt.QtPropertyWriter(name="stencilFunction")
    public final void setStencilFunction(io.qt.qt3d.render.QStencilTestArguments.StencilFunction stencilFunction){
        setStencilFunction_native_Qt3DRender_QStencilTestArguments_StencilFunction(QtJambi_LibraryUtilities.internal.nativeId(this), stencilFunction.value());
    }
    
    private native void setStencilFunction_native_Qt3DRender_QStencilTestArguments_StencilFunction(long __this__nativeId, int stencilFunction);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::stencilFunction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="stencilFunction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments.StencilFunction stencilFunction(){
        return io.qt.qt3d.render.QStencilTestArguments.StencilFunction.resolve(stencilFunction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int stencilFunction_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilTestArguments(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3drender-6.2.9-sources.jar: io/qt/qt3d/render/QStencilTestArguments.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies arguments for stencil test</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html">Qt3DRender::QStencilTestArguments</a></p>
 */
public final class QStencilTestArguments extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTestArguments.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#StencilFaceMode-enum">Qt3DRender::QStencilTestArguments::StencilFaceMode</a></p>
     */
    public enum StencilFaceMode implements io.qt.QtEnumerator {
        Front(1028),
        Back(1029),
        FrontAndBack(1032);

        private StencilFaceMode(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StencilFaceMode resolve(int value) {
            switch (value) {
            case 1028: return Front;
            case 1029: return Back;
            case 1032: return FrontAndBack;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#StencilFunction-enum">Qt3DRender::QStencilTestArguments::StencilFunction</a></p>
     */
    public enum StencilFunction implements io.qt.QtEnumerator {
        Never(512),
        Always(519),
        Less(513),
        LessOrEqual(515),
        Equal(514),
        GreaterOrEqual(518),
        Greater(516),
        NotEqual(517);

        private StencilFunction(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static StencilFunction resolve(int value) {
            switch (value) {
            case 512: return Never;
            case 519: return Always;
            case 513: return Less;
            case 515: return LessOrEqual;
            case 514: return Equal;
            case 518: return GreaterOrEqual;
            case 516: return Greater;
            case 517: return NotEqual;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::comparisonMaskChanged(uint)</a></p>
     */
    @io.qt.QtPropertyNotify(name="comparisonMask")
    public final Signal1<@io.qt.QtPrimitiveType Integer> comparisonMaskChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#faceMode-prop">Qt3DRender::QStencilTestArguments::faceModeChanged(Qt3DRender::QStencilTestArguments::StencilFaceMode)</a></p>
     */
    @io.qt.QtPropertyNotify(name="faceMode")
    public final Signal1<io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode> faceModeChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::referenceValueChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="referenceValue")
    public final Signal1<@io.qt.QtPrimitiveType Integer> referenceValueChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::stencilFunctionChanged(Qt3DRender::QStencilTestArguments::StencilFunction)</a></p>
     */
    @io.qt.QtPropertyNotify(name="stencilFunction")
    public final Signal1<io.qt.qt3d.render.QStencilTestArguments.StencilFunction> stencilFunctionChanged = new Signal1<>();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::comparisonMask()const</a></p>
     */
    @io.qt.QtPropertyReader(name="comparisonMask")
    @io.qt.QtUninvokable
    public final int comparisonMask(){
        return comparisonMask_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int comparisonMask_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#faceMode-prop">Qt3DRender::QStencilTestArguments::faceMode()const</a></p>
     */
    @io.qt.QtPropertyReader(name="faceMode")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode faceMode(){
        return io.qt.qt3d.render.QStencilTestArguments.StencilFaceMode.resolve(faceMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int faceMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::referenceValue()const</a></p>
     */
    @io.qt.QtPropertyReader(name="referenceValue")
    @io.qt.QtUninvokable
    public final int referenceValue(){
        return referenceValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int referenceValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#comparisonMask-prop">Qt3DRender::QStencilTestArguments::setComparisonMask(uint)</a></p>
     */
    @io.qt.QtPropertyWriter(name="comparisonMask")
    public final void setComparisonMask(int comparisonMask){
        setComparisonMask_native_uint(QtJambi_LibraryUtilities.internal.nativeId(this), comparisonMask);
    }
    
    private native void setComparisonMask_native_uint(long __this__nativeId, int comparisonMask);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#referenceValue-prop">Qt3DRender::QStencilTestArguments::setReferenceValue(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="referenceValue")
    public final void setReferenceValue(int referenceValue){
        setReferenceValue_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), referenceValue);
    }
    
    private native void setReferenceValue_native_int(long __this__nativeId, int referenceValue);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::setStencilFunction(Qt3DRender::QStencilTestArguments::StencilFunction)</a></p>
     */
    @io.qt.QtPropertyWriter(name="stencilFunction")
    public final void setStencilFunction(io.qt.qt3d.render.QStencilTestArguments.StencilFunction stencilFunction){
        setStencilFunction_native_Qt3DRender_QStencilTestArguments_StencilFunction(QtJambi_LibraryUtilities.internal.nativeId(this), stencilFunction.value());
    }
    
    private native void setStencilFunction_native_Qt3DRender_QStencilTestArguments_StencilFunction(long __this__nativeId, int stencilFunction);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltestarguments.html#stencilFunction-prop">Qt3DRender::QStencilTestArguments::stencilFunction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="stencilFunction")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments.StencilFunction stencilFunction(){
        return io.qt.qt3d.render.QStencilTestArguments.StencilFunction.resolve(stencilFunction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int stencilFunction_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilTestArguments(QPrivateConstructor p) { super(p); } 
    
}
